@@ -2,4 +2,4 @@ package Book;
 use Object::Simple;
 
 sub title : Attr { default => 1 }
-Object::Simple->end;
+Object::Simple->build_class;
